==> aster-full-src-7.4.0-4.tar.gz: STA7.4/bibfor/algorith/mappar.f <==
      SUBROUTINE MAPPAR(PREMIE,NOMA,DEFICO,OLDGEO,NEWGEO,COMGEO,DEPGEO)
C ======================================================================
C            CONFIGURATION MANAGEMENT OF EDF VERSION
C MODIF ALGORITH  DATE 31/08/2004   AUTEUR JMBHH01 J.M.PROIX 
C ======================================================================
C COPYRIGHT (C) 1991 - 2001  EDF R&D                  WWW.CODE-ASTER.ORG
C THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
C IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
C THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR   
C (AT YOUR OPTION) ANY LATER VERSION.                                 
C
C THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT 
C WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF          
C MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU    
C GENERAL PUBLIC LICENSE FOR MORE DETAILS.                            
C
C YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE   
C ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,       
C    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.      
C ======================================================================

      IMPLICIT NONE
      LOGICAL PREMIE
      INTEGER COMGEO
      CHARACTER*8 NOMA
      CHARACTER*24 DEFICO,NEWGEO,OLDGEO,DEPGEO

C ---------------------------------------------------------------------
C ROUTINE APPELEE PAR : OP0070
C ---------------------------------------------------------------------
C STOCKAGE DES POINTS  DE CONTACT DES SURFACES  ESCALVES ET APPARIEMENT.

C IN  NOMA   : NOM DU MAILLAGE

C VAR DEFICO : SD POUR LA DEFINITION DE CONTACT
C VAR LISTNO : SD POUR LA RESOLUTION DE PROBLEME DE CONTACT

C -------------- DEBUT DECLARATIONS NORMALISEES JEVEUX -----------------

      INTEGER ZI
      COMMON /IVARJE/ZI(1)
      REAL*8 ZR
      COMMON /RVARJE/ZR(1)
      COMPLEX*16 ZC
      COMMON /CVARJE/ZC(1)
      LOGICAL ZL
      COMMON /LVARJE/ZL(1)
      CHARACTER*8 ZK8,ALIAS
      CHARACTER*16 ZK16
      CHARACTER*24 ZK24
      CHARACTER*32 ZK32
      CHARACTER*80 ZK80
      COMMON /KVARJE/ZK8(1),ZK16(1),ZK24(1),ZK32(1),ZK80(1)

C ---------------- FIN DECLARATIONS NORMALISEES JEVEUX -----------------

      INTEGER JMACO,JMAESC,JTABF
      INTEGER NTMA,POSNO,POSMIN,JDIR
      INTEGER IZONE,TYCO,JECPD,JNORLI,ITYP,NUTYP
      INTEGER JCMCF,NTPC,IMA,POSMA,NUMAE,NBN,INI,NUMAM,LISSS,IATYMA
      REAL*8 XIMIN,YIMIN,T1MIN(3),T2MIN(3),GEOM(3),LAMBDA,XPG,YPG,HPG
      REAL*8 DIR(3),NDIR
      CHARACTER*24 COTAMA,MAESCL,CARACF,ECPDON,NORLIS,DIRCO
      CHARACTER*24 TABFIN

C ----------------------------------------------------------------------

C     LE TABLEAU  MAESCL = DEFICO(1:16)//.'MAESCL' CONTIENT LES NUMEROS
C     ABSOLUS DES MAILLES ESCLAVES ( CE NUMERO EST RECUPERE DE CONTAMA)
C     ET POUR CHAQUE MAILLE ESCLAVE LE NUMERO DE LA SA ZONE ET
C     L'INDICE DE SURFACE

      CALL JEMARQ()
C     REACTUALISATION DE LA GEOMETRIE
      CALL NMIMPR('IMPR','BCL_GEOME',' ',0.D0,COMGEO)
      CALL VTGPLD(OLDGEO,1.D0,DEPGEO,'V',NEWGEO)
      
C     RECUPERATION DE QUELQUES DONNEES      
      COTAMA = DEFICO(1:16)//'.MAILCO'
      MAESCL = DEFICO(1:16)//'.MAESCL'
      TABFIN = DEFICO(1:16)//'.TABFIN'
      CARACF = DEFICO(1:16)//'.CARACF'
      ECPDON = DEFICO(1:16)//'.ECPDON'
      NORLIS = DEFICO(1:16)//'.NORLIS'
      DIRCO  = DEFICO(1:16)//'.DIRCO'
      CALL JEVEUO(COTAMA,'L',JMACO)
      CALL JEVEUO(MAESCL,'L',JMAESC)
      CALL JEVEUO(TABFIN,'E',JTABF)
      CALL JEVEUO(CARACF,'L',JCMCF)
      CALL JEVEUO(ECPDON,'L',JECPD)
      CALL JEVEUO(NORLIS,'L',JNORLI)
      CALL JEVEUO(DIRCO,'L',JDIR)
      CALL JEVEUO(NOMA//'.TYPMAIL','L',IATYMA)  

C=======================================================================
C APPARIEMENT
C  METHODE : RECHERCHE DU NOEUD LE PLUS PROCHE ENSUITE PROJECTION
C     SUR  LES MAILLES QUI L'ENTOURANT
C=======================================================================

C CALCUL DES NORMALES 
      
      CALL LISSAG(NOMA,DEFICO,NEWGEO)

C   BOUCLE SUR LES POINTS DE CONTACT

      LAMBDA = -1.0D+6
      NTMA = ZI(JMAESC)
      NTPC = 0
      DO 20 IMA = 1,NTMA    
        POSMA = ZI(JMAESC+3* (IMA-1)+1)
        NUMAE = ZI(JMACO+POSMA-1)
        IZONE = ZI(JMAESC+3* (IMA-1)+2)
        NBN = ZI(JMAESC+3* (IMA-1)+3)
        TYCO = NINT(ZR(JCMCF+6* (IZONE-1)+1))
        LISSS= ZI(JNORLI+IZONE-1+1)
        LAMBDA = -ABS(ZI(JECPD+6*(IZONE-1)+5))
        DIR(1)= ZR(JDIR+3* (IZONE-1)) 
        DIR(2)= ZR(JDIR+3* (IZONE-1)+1)  
        DIR(3)= ZR(JDIR+3* (IZONE-1)+2) 
        NDIR =SQRT(DIR(1)*DIR(1)+DIR(2)*DIR(2)+DIR(3)*DIR(3))
           ITYP = IATYMA - 1 + NUMAE
           NUTYP = ZI(ITYP)
           IF (NUTYP.EQ.2) THEN
             ALIAS(1:3) = 'SG2'
           ELSE IF (NUTYP.EQ.4) THEN
             ALIAS(1:3) = 'SG3'
           ELSE IF (NUTYP.EQ.7) THEN
             ALIAS(1:3) = 'TR3'
           ELSE IF (NUTYP.EQ.9) THEN
             ALIAS(1:3) = 'TR6'
           ELSE IF (NUTYP.EQ.12) THEN
             ALIAS(1:3) = 'QU4'
           ELSE IF (NUTYP.EQ.14) THEN
             ALIAS(1:3) = 'QU8'
           ELSE IF (NUTYP.EQ.16) THEN
             ALIAS(1:3) = 'QU9'
           ELSE
            CALL UTMESS('F','COPCO','STOP_1')
           END IF

        DO 10 INI = 1,NBN 
           
          CALL GAUSS2(ALIAS,TYCO,XPG,YPG,INI,HPG)
          CALL COPCOG(NOMA,POSMA,XPG,YPG,NEWGEO,GEOM,DEFICO)

          IF (NDIR.GT.0.D0) THEN
            CALL MRECHD(IZONE,GEOM,NEWGEO,DEFICO,POSNO,DIR)
            CALL MCHMPD(NOMA,GEOM,POSNO,NEWGEO,DEFICO,POSMIN,T1MIN,
     &               T2MIN,XIMIN,YIMIN,DIR)
          ELSE
             CALL MRECHN(IZONE,GEOM,NEWGEO,DEFICO,POSNO)
             CALL MCHMPS(NOMA,GEOM,POSNO,NEWGEO,DEFICO,POSMIN,T1MIN,
     &               T2MIN,XIMIN,YIMIN)
          NUMAM = ZI(JMACO+POSMIN-1)
          ENDIF
      
          IF (LISSS.EQ.1) THEN 
          CALL COPNOR(NOMA,POSMIN,XIMIN,YIMIN,NEWGEO,DEFICO,
     &    T1MIN,T2MIN)
          END IF
          ZR(JTABF+16*NTPC+16* (INI-1)+1) = NUMAE
          ZR(JTABF+16*NTPC+16* (INI-1)+2) = NUMAM
          ZR(JTABF+16*NTPC+16* (INI-1)+3) = XPG
          ZR(JTABF+16*NTPC+16* (INI-1)+4) = XIMIN
          ZR(JTABF+16*NTPC+16* (INI-1)+5) = YIMIN
          ZR(JTABF+16*NTPC+16* (INI-1)+6) = T1MIN(1)
          ZR(JTABF+16*NTPC+16* (INI-1)+7) = T1MIN(2)
          ZR(JTABF+16*NTPC+16* (INI-1)+8) = T1MIN(3)
          ZR(JTABF+16*NTPC+16* (INI-1)+9) = T2MIN(1)
          ZR(JTABF+16*NTPC+16* (INI-1)+10) = T2MIN(2)
          ZR(JTABF+16*NTPC+16* (INI-1)+11) = T2MIN(3)
          ZR(JTABF+16*NTPC+16* (INI-1)+12) = YPG
          IF (PREMIE) ZR(JTABF+16*NTPC+16* (INI-1)+13) = 0.D0
          IF (PREMIE) ZR(JTABF+16*NTPC+16* (INI-1)+14) = LAMBDA
          ZR(JTABF+16*NTPC+16* (INI-1)+15) = IZONE
          ZR(JTABF+16*NTPC+16* (INI-1)+16) = HPG          
   10   CONTINUE
        NTPC = NTPC + NBN
   20 CONTINUE
       
      ZR(JTABF-1+1) = NTPC
      CALL JEDEMA()
      END

==> aster-full-src-8.1.0-1.tar.gz: STA8.1/bibfor/algorith/mappar.f <==
      SUBROUTINE MAPPAR(PREMIE,NOMA,DEFICO,OLDGEO,NEWGEO,COMGEO,DEPGEO)
C ======================================================================
C            CONFIGURATION MANAGEMENT OF EDF VERSION
C MODIF ALGORITH  DATE 08/03/2005   AUTEUR LAMARCHE S.LAMARCHE 
C ======================================================================
C COPYRIGHT (C) 1991 - 2001  EDF R&D                  WWW.CODE-ASTER.ORG
C THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
C IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
C THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR   
C (AT YOUR OPTION) ANY LATER VERSION.                                 
C
C THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT 
C WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF          
C MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU    
C GENERAL PUBLIC LICENSE FOR MORE DETAILS.                            
C
C YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE   
C ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,       
C    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.      
C ======================================================================

      IMPLICIT NONE
      LOGICAL PREMIE
      INTEGER COMGEO
      CHARACTER*8 NOMA
      CHARACTER*24 DEFICO,NEWGEO,OLDGEO,DEPGEO

C ---------------------------------------------------------------------
C ROUTINE APPELEE PAR : OP0070
C ---------------------------------------------------------------------
C STOCKAGE DES POINTS  DE CONTACT DES SURFACES  ESCALVES ET APPARIEMENT.

C IN  NOMA   : NOM DU MAILLAGE

C VAR DEFICO : SD POUR LA DEFINITION DE CONTACT
C VAR LISTNO : SD POUR LA RESOLUTION DE PROBLEME DE CONTACT

C -------------- DEBUT DECLARATIONS NORMALISEES JEVEUX -----------------

      INTEGER ZI
      COMMON /IVARJE/ZI(1)
      REAL*8 ZR
      COMMON /RVARJE/ZR(1)
      COMPLEX*16 ZC
      COMMON /CVARJE/ZC(1)
      LOGICAL ZL
      COMMON /LVARJE/ZL(1)
      CHARACTER*8 ZK8,ALIAS
      CHARACTER*16 ZK16
      CHARACTER*24 ZK24
      CHARACTER*32 ZK32
      CHARACTER*80 ZK80
      COMMON /KVARJE/ZK8(1),ZK16(1),ZK24(1),ZK32(1),ZK80(1)

C ---------------- FIN DECLARATIONS NORMALISEES JEVEUX -----------------

      INTEGER JMACO,JMAESC,JTABF
      INTEGER NTMA,POSNO,POSMIN,JDIR
      INTEGER IZONE,TYCO,JECPD,JNORLI,ITYP,NUTYP
      INTEGER JCMCF,NTPC,IMA,POSMA,NUMAE,NBN,INI,NUMAM,LISSS,IATYMA
      REAL*8 XIMIN,YIMIN,T1MIN(3),T2MIN(3),GEOM(3),LAMBDA,XPG,YPG,HPG
      REAL*8 DIR(3),NDIR
      CHARACTER*24 COTAMA,MAESCL,CARACF,ECPDON,NORLIS,DIRCO
      CHARACTER*24 TABFIN

C ----------------------------------------------------------------------

C     LE TABLEAU  MAESCL = DEFICO(1:16)//.'MAESCL' CONTIENT LES NUMEROS
C     ABSOLUS DES MAILLES ESCLAVES ( CE NUMERO EST RECUPERE DE CONTAMA)
C     ET POUR CHAQUE MAILLE ESCLAVE LE NUMERO DE LA SA ZONE ET
C     L'INDICE DE SURFACE

      CALL JEMARQ()
C     REACTUALISATION DE LA GEOMETRIE
      CALL NMIMPR('IMPR','BCL_GEOME',' ',0.D0,COMGEO)
      CALL VTGPLD(OLDGEO,1.D0,DEPGEO,'V',NEWGEO)
      
C     RECUPERATION DE QUELQUES DONNEES      
      COTAMA = DEFICO(1:16)//'.MAILCO'
      MAESCL = DEFICO(1:16)//'.MAESCL'
      TABFIN = DEFICO(1:16)//'.TABFIN'
      CARACF = DEFICO(1:16)//'.CARACF'
      ECPDON = DEFICO(1:16)//'.ECPDON'
      NORLIS = DEFICO(1:16)//'.NORLIS'
      DIRCO  = DEFICO(1:16)//'.DIRCO'
      CALL JEVEUO(COTAMA,'L',JMACO)
      CALL JEVEUO(MAESCL,'L',JMAESC)
      CALL JEVEUO(TABFIN,'E',JTABF)
      CALL JEVEUO(CARACF,'L',JCMCF)
      CALL JEVEUO(ECPDON,'L',JECPD)
      CALL JEVEUO(NORLIS,'L',JNORLI)
      CALL JEVEUO(DIRCO,'L',JDIR)
      CALL JEVEUO(NOMA//'.TYPMAIL','L',IATYMA)  

C=======================================================================
C APPARIEMENT
C  METHODE : RECHERCHE DU NOEUD LE PLUS PROCHE ENSUITE PROJECTION
C     SUR  LES MAILLES QUI L'ENTOURANT
C=======================================================================

C CALCUL DES NORMALES 
      
      CALL LISSAG(NOMA,DEFICO,NEWGEO)

C   BOUCLE SUR LES POINTS DE CONTACT

      LAMBDA = -1.0D+6
      NTMA = ZI(JMAESC)
      NTPC = 0
      DO 20 IMA = 1,NTMA    
        POSMA = ZI(JMAESC+3* (IMA-1)+1)
        NUMAE = ZI(JMACO+POSMA-1)
        IZONE = ZI(JMAESC+3* (IMA-1)+2)
        NBN = ZI(JMAESC+3* (IMA-1)+3)
        TYCO = NINT(ZR(JCMCF+6* (IZONE-1)+1))
        LISSS= ZI(JNORLI+IZONE-1+1)
        LAMBDA = -ABS(ZR(JCMCF+6*(IZONE-1)+6))
        DIR(1)= ZR(JDIR+3* (IZONE-1)) 
        DIR(2)= ZR(JDIR+3* (IZONE-1)+1)  
        DIR(3)= ZR(JDIR+3* (IZONE-1)+2) 
        NDIR =SQRT(DIR(1)*DIR(1)+DIR(2)*DIR(2)+DIR(3)*DIR(3))
           ITYP = IATYMA - 1 + NUMAE
           NUTYP = ZI(ITYP)
           IF (NUTYP.EQ.2) THEN
             ALIAS(1:3) = 'SG2'
           ELSE IF (NUTYP.EQ.4) THEN
             ALIAS(1:3) = 'SG3'
           ELSE IF (NUTYP.EQ.7) THEN
             ALIAS(1:3) = 'TR3'
           ELSE IF (NUTYP.EQ.9) THEN
             ALIAS(1:3) = 'TR6'
           ELSE IF (NUTYP.EQ.12) THEN
             ALIAS(1:3) = 'QU4'
           ELSE IF (NUTYP.EQ.14) THEN
             ALIAS(1:3) = 'QU8'
           ELSE IF (NUTYP.EQ.16) THEN
             ALIAS(1:3) = 'QU9'
           ELSE
            CALL UTMESS('F','COPCO','STOP_1')
           END IF

        DO 10 INI = 1,NBN 
           
          CALL GAUSS2(ALIAS,TYCO,XPG,YPG,INI,HPG)
          CALL COPCOG(NOMA,POSMA,XPG,YPG,NEWGEO,GEOM,DEFICO)

          IF (NDIR.GT.0.D0) THEN
            CALL MRECHD(IZONE,GEOM,NEWGEO,DEFICO,POSNO,DIR)
            CALL MCHMPD(NOMA,GEOM,POSNO,NEWGEO,DEFICO,POSMIN,T1MIN,
     &               T2MIN,XIMIN,YIMIN,DIR)
          ELSE
             CALL MRECHN(IZONE,GEOM,NEWGEO,DEFICO,POSNO)
             CALL MCHMPS(NOMA,GEOM,POSNO,NEWGEO,DEFICO,POSMIN,T1MIN,
     &               T2MIN,XIMIN,YIMIN)
          NUMAM = ZI(JMACO+POSMIN-1)
          ENDIF
      
          IF (LISSS.EQ.1) THEN 
          CALL COPNOR(NOMA,POSMIN,XIMIN,YIMIN,NEWGEO,DEFICO,
     &    T1MIN,T2MIN)
          END IF
          ZR(JTABF+16*NTPC+16* (INI-1)+1) = NUMAE
          ZR(JTABF+16*NTPC+16* (INI-1)+2) = NUMAM
          ZR(JTABF+16*NTPC+16* (INI-1)+3) = XPG
          ZR(JTABF+16*NTPC+16* (INI-1)+4) = XIMIN
          ZR(JTABF+16*NTPC+16* (INI-1)+5) = YIMIN
          ZR(JTABF+16*NTPC+16* (INI-1)+6) = T1MIN(1)
          ZR(JTABF+16*NTPC+16* (INI-1)+7) = T1MIN(2)
          ZR(JTABF+16*NTPC+16* (INI-1)+8) = T1MIN(3)
          ZR(JTABF+16*NTPC+16* (INI-1)+9) = T2MIN(1)
          ZR(JTABF+16*NTPC+16* (INI-1)+10) = T2MIN(2)
          ZR(JTABF+16*NTPC+16* (INI-1)+11) = T2MIN(3)
          ZR(JTABF+16*NTPC+16* (INI-1)+12) = YPG
          IF (PREMIE) THEN
          IF (ZI(JECPD+6*(IZONE-1)+5).EQ.1.D0) THEN 
          ZR(JTABF+16*NTPC+16* (INI-1)+13) = 1.D0
          ELSE 
          ZR(JTABF+16*NTPC+16* (INI-1)+13) = 0.D0
          END IF
          END IF
          IF (PREMIE) ZR(JTABF+16*NTPC+16* (INI-1)+14) = LAMBDA
          ZR(JTABF+16*NTPC+16* (INI-1)+15) = IZONE
          ZR(JTABF+16*NTPC+16* (INI-1)+16) = HPG          
   10   CONTINUE
        NTPC = NTPC + NBN
   20 CONTINUE
       
      ZR(JTABF-1+1) = NTPC
      CALL JEDEMA()
      END
